@@ -5,7 +5,7 @@ echo "Creating:"
 #
 # Don't do this for config.mk and clean_all.mk, they contain NT specific options
 #
-for i in mk/cross mk/dynlink mk/files mk/install \
+for i in mk/dynlink mk/files mk/install \
     mk/main mk/mmm mk/ocaml mk/ocamlopt mk/preamble \
     mk/sub mk/tools; do
       echo "  " $i
@@ -14,8 +14,7 @@ done
 
 for i in demo/Makefile demo/Makefile.base demo/Makefile.opt \
     demo/life/Makefile demo/tk/Makefile demo/dbm/Makefile \
-    Makefile .depend lib/Makefile def/Makefile def/.depend \
-    opt/Makefile opt/.depend ; do
+    Makefile ce/Makefile ; do
       echo "  " $i
       sed -f tools/ntify.sed $i > $i.nt
 done
@@ -23,8 +22,8 @@ done
 #
 # Don't do this for maestro and ejava: they have their own build process.
 #
-for i in appl doc layers socket buffer lib groupd tools crypto \
-         hot trans infr route type rpc util; do
+for i in appl buffer crypto def doc groupd hot infr \
+	 layers lib mk opt route rpc socket trans tools type util; do
       echo "  " $i/Makefile
       sed -f tools/ntify.sed $i/Makefile > $i/Makefile.nt
 done
