@@ -1,13 +1,4 @@
 (**************************************************************)
-(*
- *  Ensemble, 1.10
- *  Copyright 2001 Cornell University, Hebrew University
- *  All rights reserved.
- *
- *  See ensemble/doc/license.txt for further information.
- *)
-(**************************************************************)
-(**************************************************************)
 (* UTIL.ML *)
 (* Author: Mark Hayden, 4/95 *)
 (**************************************************************)
@@ -576,11 +567,6 @@ let strtok s c =
 
 (**************************************************************)
 
-let string_of_eth eth =
-  hex_of_string (Hsys.eth_to_bin_string eth)
-
-(**************************************************************)
-
 let string_of_id debug mapping key =
   let mapping = Array.to_list mapping in
   let mapping = List.map (fun (a,b) -> (b,a)) mapping in
